@@ -3,13 +3,13 @@ package App::cpanminus::reporter;
 use warnings;
 use strict;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Carp ();
 use File::Spec     3.19;
 use File::HomeDir  0.58 ();
 use Test::Reporter 1.54;
-use CPAN::Testers::Common::Client 0.11;
+use CPAN::Testers::Common::Client 0.12;
 use CPAN::Testers::Common::Client::Config;
 use Parse::CPAN::Meta;
 use CPAN::Meta::Converter;
@@ -259,11 +259,15 @@ sub run {
       elsif ( /^Entering (\S+)/ ) {
         my $dep = $1;
         $found = 1;
-        Carp::croak 'Parsing error. This should not happen. Please send us a report!' if $recording && $recording eq 'test';
-        print "entering $dep, " . ($fetched || '(local)') . "\n" if $self->verbose;
-        $parser->($dep, $fetched);
-        print "left $dep, " . ($fetched || '(local)') . "\n" if $self->verbose;
-        next;
+        if ($recording && $recording eq 'test') {
+            Carp::croak 'Parsing error. This should not happen. Please send us a report!';
+        }
+        else {
+            print "entering $dep, " . ($fetched || '(local)') . "\n" if $self->verbose;
+            $parser->($dep, $fetched);
+            print "left $dep, " . ($fetched || '(local)') . "\n" if $self->verbose;
+            next;
+        }
       }
       elsif ( /^Running (?:Build|Makefile)\.PL/ ) {
         $recording = 'configure';
